package net.knarcraft.blacksmith.command.scrapper;

import net.knarcraft.blacksmith.BlacksmithPlugin;
import net.knarcraft.blacksmith.command.ReloadCommand;
import net.knarcraft.blacksmith.config.scrapper.GlobalScrapperSettings;
import net.knarcraft.blacksmith.config.scrapper.ScrapperSetting;
import net.knarcraft.blacksmith.util.ConfigCommandHelper;
import net.knarcraft.blacksmith.util.TypeValidationHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

/**
 * The command used for changing global scrapper configuration options
 */
public class ScrapperConfigCommand implements CommandExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label,
                             @NotNull String[] args) {
        if (args.length == 0) {
            return false;
        }

        String commandName = args[0];
        if (commandName.equalsIgnoreCase("reload")) {
            return new ReloadCommand().onCommand(sender, command, label, args);
        }
        GlobalScrapperSettings settings = BlacksmithPlugin.getInstance().getGlobalScrapperSettings();

        //Find which setting the user has specified, if any
        ScrapperSetting detectedSetting = ScrapperSetting.getSetting(commandName);
        if (detectedSetting == null) {
            return false;
        }

        //Display the current value of a setting
        if (args.length == 1) {
            ConfigCommandHelper.displayCurrentValue(detectedSetting, settings, sender);
            return true;
        }

        //Change the value of the specified setting
        if (TypeValidationHelper.isValid(detectedSetting.getValueType(), args[1], sender)) {
            ConfigCommandHelper.changeValue(args, detectedSetting, settings, sender);
            return true;
        } else {
            return false;
        }
    }

}
