package net.knarcraft.blacksmith.config;

public interface TraitSettings<K extends Setting> extends Settings<K> {

    /**
     * Gets whether to disable the action cool-down
     *
     * @return <p>Whether to disable the action cool-down</p>
     */
    boolean getDisableCoolDown();

    /**
     * Gets the message to display when a blacksmith or scrapper is still affected by a cool-down
     *
     * @return <p>The cool down unexpired message</p>
     */
    String getCoolDownUnexpiredMessage();

    /**
     * Gets the message to display when the blacksmith is busy with another player
     *
     * @return <p>The busy with player message</p>
     */
    String getBusyWithPlayerMessage();

    /**
     * Gets the message to display when the blacksmith is busy with reforging or salvaging an item
     *
     * @return <p>The busy working message</p>
     */
    String getBusyWorkingMessage();

    /**
     * Gets the message to display when a blacksmith starts reforging or salvaging an item
     *
     * @return <p>The start working message</p>
     */
    String getStartWorkingMessage();

}
