package net.knarcraft.blacksmith.event;

import net.citizensnpcs.api.npc.NPC;
import org.bukkit.Material;
import org.bukkit.entity.Entity;
import org.bukkit.entity.Player;
import org.bukkit.event.HandlerList;
import org.jetbrains.annotations.NotNull;

/**
 * The event triggered when a blacksmith reforging starts
 */
public class BlacksmithReforgeStartEvent extends AbstractBlacksmithPluginEvent implements ActionStartEvent {

    private static final HandlerList handlers = new HandlerList();
    private final long durationTicks;
    private final Material craftingStation;

    /**
     * Instantiates a new blacksmith reforge start event
     *
     * @param npc             <p>The NPC involved in the event</p>
     * @param entity          <p>The entity of the NPC</p>
     * @param player          <p>The player involved in the event</p>
     * @param durationTicks   <p>The duration of the reforge</p>
     * @param craftingStation <p>The appropriate crafting station for this reforging</p>
     */
    public BlacksmithReforgeStartEvent(@NotNull NPC npc, @NotNull Entity entity, @NotNull Player player, long durationTicks,
                                       @NotNull Material craftingStation) {
        super(npc, entity, player);
        this.durationTicks = durationTicks;
        this.craftingStation = craftingStation;
    }

    @Override
    public long getActionDurationTicks() {
        return durationTicks;
    }

    @Override
    public Material getCraftingStation() {
        return craftingStation;
    }

    /**
     * Gets a handler-list containing all event handlers
     *
     * @return <p>A handler-list with all event handlers</p>
     */
    @NotNull
    @SuppressWarnings("unused")
    public static HandlerList getHandlerList() {
        return handlers;
    }

    @Override
    @NotNull
    public HandlerList getHandlers() {
        return handlers;
    }

}
